=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2010-12-08 18:53:46 +0000
+++ drizzled/db.cc	2010-12-18 05:18:30 +0000
@@ -619,7 +619,7 @@
 bool mysql_change_db(Session *session, SchemaIdentifier &schema_identifier)
 {
 
-  if (not plugin::Authorization::isAuthorized(session->getSecurityContext(), schema_identifier))
+  if (not plugin::Authorization::isAuthorized(session->user(), schema_identifier))
   {
     /* Error message is set in isAuthorized */
     return true;

=== modified file 'drizzled/execute.cc'
--- drizzled/execute.cc	2010-12-08 02:27:22 +0000
+++ drizzled/execute.cc	2010-12-18 05:18:30 +0000
@@ -64,7 +64,7 @@
     // Overwrite the context in the next session, with what we have in our
     // session. Eventually we will allow someone to change the effective
     // user.
-    new_session->getSecurityContext()= _session.getSecurityContext();
+    new_session->user()= _session.user();
 
     if (Session::schedule(new_session))
     {

=== modified file 'drizzled/identifier.h'
--- drizzled/identifier.h	2010-07-15 23:18:11 +0000
+++ drizzled/identifier.h	2010-12-18 05:18:30 +0000
@@ -23,5 +23,6 @@
 
 #include "drizzled/identifier/schema.h"
 #include "drizzled/identifier/table.h"
+#include "drizzled/identifier/user.h"
 
 #endif /* DRIZZLED_IDENTIFIER_H */

=== added file 'drizzled/identifier/user.cc'
--- drizzled/identifier/user.cc	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/user.cc	2010-12-18 05:18:30 +0000
@@ -0,0 +1,36 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "drizzled/identifier/user.h"
+
+namespace drizzled
+{
+namespace identifier
+{
+
+User::shared_ptr User::make_shared()
+{
+  return shared_ptr(new User);
+}
+
+
+} /* namespace identifier */
+} /* namespace drizzled */

=== added file 'drizzled/identifier/user.h'
--- drizzled/identifier/user.h	1970-01-01 00:00:00 +0000
+++ drizzled/identifier/user.h	2010-12-18 05:18:30 +0000
@@ -0,0 +1,106 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#ifndef DRIZZLED_IDENTIFIER_USER_H
+#define DRIZZLED_IDENTIFIER_USER_H
+
+#include <string>
+#include <boost/shared_ptr.hpp>
+
+namespace drizzled
+{
+namespace identifier
+{
+
+/**
+  @class User
+  @brief A set of Session members describing the current authenticated user.
+*/
+
+class User {
+public:
+  typedef boost::shared_ptr<User> shared_ptr;
+  typedef boost::shared_ptr<const User> const_shared_ptr;
+  static shared_ptr make_shared();
+
+  enum PasswordType
+  {
+    PLAIN_TEXT,
+    MYSQL_HASH
+  };
+
+  User():
+    password_type(PLAIN_TEXT),
+    _user(""),
+    _address("")
+  { }
+
+  const std::string& address() const
+  {
+    return _address;
+  }
+
+  void setAddress(const char *newip)
+  {
+    _address.assign(newip);
+  }
+
+  const std::string& username() const
+  {
+    return _user;
+  }
+
+  void setUser(const std::string &newuser)
+  {
+    _user.assign(newuser);
+  }
+
+  PasswordType getPasswordType(void) const
+  {
+    return password_type;
+  }
+
+  void setPasswordType(PasswordType newpassword_type)
+  {
+    password_type= newpassword_type;
+  }
+
+  const std::string& getPasswordContext() const
+  {
+    return password_context;
+  }
+
+  void setPasswordContext(const char *newpassword_context, size_t size)
+  {
+    password_context.assign(newpassword_context, size);
+  }
+
+private:
+  PasswordType password_type;
+  std::string _user;
+  std::string _address;
+  std::string password_context;
+};
+
+} /* namespace identifier */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_IDENTIFIER_USER_H */

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-12-18 00:43:02 +0000
+++ drizzled/include.am	2010-12-18 06:42:10 +0000
@@ -206,6 +206,7 @@
 			      drizzled/identifier.h \
 			      drizzled/identifier/schema.h \
 			      drizzled/identifier/table.h \
+			      drizzled/identifier/user.h \
 			      drizzled/index_hint.h \
 			      drizzled/internal_error_handler.h \
 			      drizzled/item.h \
@@ -345,7 +346,6 @@
 			      drizzled/records.h \
 			      drizzled/replication_services.h \
 			      drizzled/resource_context.h \
-			      drizzled/security_context.h \
 			      drizzled/select_create.h \
 			      drizzled/select_dump.h \
 			      drizzled/select_dumpvar.h \
@@ -621,6 +621,7 @@
 			   drizzled/hybrid_type_traits_integer.cc \
 			   drizzled/identifier/schema.cc \
 			   drizzled/identifier/table.cc \
+			   drizzled/identifier/user.cc \
 			   drizzled/index_hint.cc \
 			   drizzled/item.cc \
 			   drizzled/item/bin_string.cc \

=== modified file 'drizzled/plugin/authentication.cc'
--- drizzled/plugin/authentication.cc	2010-12-04 01:01:46 +0000
+++ drizzled/plugin/authentication.cc	2010-12-18 05:18:30 +0000
@@ -22,7 +22,7 @@
 #include "drizzled/plugin/authentication.h"
 #include "drizzled/error.h"
 #include "drizzled/gettext.h"
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 
 #include <vector>
 
@@ -36,6 +36,7 @@
 {
   if (auth != NULL)
     all_authentication.push_back(auth);
+
   return false;
 }
 
@@ -49,10 +50,11 @@
 
 class AuthenticateBy : public std::unary_function<plugin::Authentication *, bool>
 {
-  const SecurityContext &sctx;
+  const identifier::User &sctx;
   const std::string &password;
+
 public:
-  AuthenticateBy(const SecurityContext &sctx_arg, const std::string &password_arg) :
+  AuthenticateBy(const identifier::User &sctx_arg, const std::string &password_arg) :
     std::unary_function<plugin::Authentication *, bool>(),
     sctx(sctx_arg), password(password_arg) {}
 
@@ -62,7 +64,7 @@
   }
 };
 
-bool plugin::Authentication::isAuthenticated(const SecurityContext &sctx,
+bool plugin::Authentication::isAuthenticated(drizzled::identifier::User::const_shared_ptr sctx,
                                              const std::string &password)
 {
   /* If we never loaded any auth plugins, just return true */
@@ -72,7 +74,7 @@
   /* Use find_if instead of foreach so that we can collect return codes */
   std::vector<plugin::Authentication *>::iterator iter=
     std::find_if(all_authentication.begin(), all_authentication.end(),
-                 AuthenticateBy(sctx, password));
+                 AuthenticateBy(*sctx, password));
 
   /* We only require one plugin to return success in order to authenticate.
    * If iter is == end() here, that means that all of the plugins returned
@@ -81,11 +83,13 @@
   if (iter == all_authentication.end())
   {
     my_error(ER_ACCESS_DENIED_ERROR, MYF(0),
-             sctx.getUser().c_str(),
-             sctx.getIp().c_str(),
+             sctx->username().c_str(),
+             sctx->address().c_str(),
              password.empty() ? ER(ER_NO) : ER(ER_YES));
+
     return false;
   }
+
   return true;
 }
 

=== modified file 'drizzled/plugin/authentication.h'
--- drizzled/plugin/authentication.h	2010-03-02 18:33:15 +0000
+++ drizzled/plugin/authentication.h	2010-12-18 05:18:30 +0000
@@ -26,10 +26,14 @@
 
 #include "drizzled/plugin.h"
 #include "drizzled/plugin/plugin.h"
+#include "drizzled/identifier.h"
 
 namespace drizzled
 {
-class SecurityContext;
+
+namespace identifier {
+class User;
+} 
 
 namespace plugin
 {
@@ -45,12 +49,12 @@
   {}
   virtual ~Authentication() {}
 
-  virtual bool authenticate(const SecurityContext &sctx,
+  virtual bool authenticate(const identifier::User &sctx,
                             const std::string &passwd)= 0;
 
   static bool addPlugin(plugin::Authentication *auth);
   static void removePlugin(plugin::Authentication *auth);
-  static bool isAuthenticated(const SecurityContext &sctx,
+  static bool isAuthenticated(drizzled::identifier::User::const_shared_ptr sctx,
                               const std::string &password);
 };
 

=== modified file 'drizzled/plugin/authorization.cc'
--- drizzled/plugin/authorization.cc	2010-12-11 17:34:45 +0000
+++ drizzled/plugin/authorization.cc	2010-12-18 05:18:30 +0000
@@ -23,7 +23,6 @@
 #include <vector>
 
 #include "drizzled/plugin/authorization.h"
-#include "drizzled/security_context.h"
 #include "drizzled/identifier.h"
 #include "drizzled/error.h"
 #include "drizzled/session.h"
@@ -59,11 +58,11 @@
 class RestrictDbFunctor :
   public std::unary_function<plugin::Authorization *, bool>
 {
-  const SecurityContext &user_ctx;
+  const identifier::User &user_ctx;
   SchemaIdentifier::const_reference schema;
 
 public:
-  RestrictDbFunctor(const SecurityContext &user_ctx_arg,
+  RestrictDbFunctor(const identifier::User &user_ctx_arg,
                     SchemaIdentifier::const_reference schema_arg) :
     std::unary_function<plugin::Authorization *, bool>(),
     user_ctx(user_ctx_arg),
@@ -79,10 +78,10 @@
 class RestrictTableFunctor :
   public std::unary_function<plugin::Authorization *, bool>
 {
-  const SecurityContext &user_ctx;
+  const identifier::User &user_ctx;
   TableIdentifier &table;
 public:
-  RestrictTableFunctor(const SecurityContext &user_ctx_arg,
+  RestrictTableFunctor(const identifier::User &user_ctx_arg,
                        TableIdentifier &table_arg) :
     std::unary_function<plugin::Authorization *, bool>(),
     user_ctx(user_ctx_arg),
@@ -98,11 +97,11 @@
 class RestrictProcessFunctor :
   public std::unary_function<plugin::Authorization *, bool>
 {
-  const SecurityContext &user_ctx;
-  const SecurityContext &session_ctx;
+  const identifier::User &user_ctx;
+  const identifier::User &session_ctx;
 public:
-  RestrictProcessFunctor(const SecurityContext &user_ctx_arg,
-                         const SecurityContext &session_ctx_arg) :
+  RestrictProcessFunctor(const identifier::User &user_ctx_arg,
+                         const identifier::User &session_ctx_arg) :
     std::unary_function<plugin::Authorization *, bool>(),
     user_ctx(user_ctx_arg),
     session_ctx(session_ctx_arg)
@@ -117,9 +116,9 @@
 class PruneSchemaFunctor :
   public std::unary_function<SchemaIdentifier&, bool>
 {
-  const SecurityContext &user_ctx;
+  drizzled::identifier::User::const_shared_ptr user_ctx;
 public:
-  PruneSchemaFunctor(const SecurityContext &user_ctx_arg) :
+  PruneSchemaFunctor(drizzled::identifier::User::const_shared_ptr user_ctx_arg) :
     std::unary_function<SchemaIdentifier&, bool>(),
     user_ctx(user_ctx_arg)
   { }
@@ -132,7 +131,7 @@
 
 } /* namespace */
 
-bool plugin::Authorization::isAuthorized(const SecurityContext &user_ctx,
+bool plugin::Authorization::isAuthorized(identifier::User::const_shared_ptr user_ctx,
                                          SchemaIdentifier::const_reference schema_identifier,
                                          bool send_error)
 {
@@ -144,7 +143,7 @@
   std::vector<plugin::Authorization *>::const_iterator iter=
     std::find_if(authorization_plugins.begin(),
                  authorization_plugins.end(),
-                 RestrictDbFunctor(user_ctx, schema_identifier));
+                 RestrictDbFunctor(*user_ctx, schema_identifier));
 
 
   /*
@@ -160,8 +159,8 @@
       schema_identifier.getSQLPath(path);
 
       my_error(ER_DBACCESS_DENIED_ERROR, MYF(0),
-               user_ctx.getUser().c_str(),
-               user_ctx.getIp().c_str(),
+               user_ctx->username().c_str(),
+               user_ctx->address().c_str(),
                path.c_str());
     }
     return false;
@@ -169,7 +168,7 @@
   return true;
 }
 
-bool plugin::Authorization::isAuthorized(const SecurityContext &user_ctx,
+bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
                                          TableIdentifier &table,
                                          bool send_error)
 {
@@ -181,7 +180,7 @@
   std::vector<plugin::Authorization *>::const_iterator iter=
     std::find_if(authorization_plugins.begin(),
             authorization_plugins.end(),
-            RestrictTableFunctor(user_ctx, table));
+            RestrictTableFunctor(*user_ctx, table));
 
   /*
    * If iter is == end() here, that means that all of the plugins returned
@@ -196,8 +195,8 @@
       table.getSQLPath(path);
 
       my_error(ER_DBACCESS_DENIED_ERROR, MYF(0),
-               user_ctx.getUser().c_str(),
-               user_ctx.getIp().c_str(),
+               user_ctx->username().c_str(),
+               user_ctx->address().c_str(),
                path.c_str());
     }
     return false;
@@ -205,11 +204,11 @@
   return true;
 }
 
-bool plugin::Authorization::isAuthorized(const SecurityContext &user_ctx,
+bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
                                          const Session *session,
                                          bool send_error)
 {
-  const SecurityContext &session_ctx= session->getSecurityContext();
+  drizzled::identifier::User::const_shared_ptr session_ctx= session->user();
 
   /* If we never loaded any authorization plugins, just return true */
   if (authorization_plugins.empty())
@@ -219,7 +218,7 @@
   std::vector<plugin::Authorization *>::const_iterator iter=
     std::find_if(authorization_plugins.begin(),
                  authorization_plugins.end(),
-                 RestrictProcessFunctor(user_ctx, session_ctx));
+                 RestrictProcessFunctor(*user_ctx, *session_ctx));
 
   /*
    * If iter is == end() here, that means that all of the plugins returned
@@ -238,7 +237,7 @@
   return true;
 }
 
-void plugin::Authorization::pruneSchemaNames(const SecurityContext &user_ctx,
+void plugin::Authorization::pruneSchemaNames(drizzled::identifier::User::const_shared_ptr user_ctx,
                                              SchemaIdentifier::vector &set_of_schemas)
 {
   /* If we never loaded any authorization plugins, just return true */

=== modified file 'drizzled/plugin/authorization.h'
--- drizzled/plugin/authorization.h	2010-12-11 17:34:45 +0000
+++ drizzled/plugin/authorization.h	2010-12-18 05:18:30 +0000
@@ -24,7 +24,6 @@
 
 #include "drizzled/plugin.h"
 #include "drizzled/plugin/plugin.h"
-#include "drizzled/security_context.h"
 #include "drizzled/identifier.h"
 
 #include <string>
@@ -55,7 +54,7 @@
    *
    * @returns true if the user cannot access the schema
    */
-  virtual bool restrictSchema(const SecurityContext &user_ctx,
+  virtual bool restrictSchema(const drizzled::identifier::User &user_ctx,
                               SchemaIdentifier::const_reference schema)= 0;
 
   /**
@@ -67,7 +66,7 @@
    *
    * @returns true if the user cannot access the table
    */
-  virtual bool restrictTable(const SecurityContext &user_ctx,
+  virtual bool restrictTable(const drizzled::identifier::User &user_ctx,
                              TableIdentifier &table);
 
   /**
@@ -79,21 +78,21 @@
    *
    * @returns true if the user cannot see the process
    */
-  virtual bool restrictProcess(const SecurityContext &user_ctx,
-                               const SecurityContext &session_ctx);
+  virtual bool restrictProcess(const drizzled::identifier::User &user_ctx,
+                               const drizzled::identifier::User &session_ctx);
 
   /** Server API method for checking schema authorization */
-  static bool isAuthorized(const SecurityContext &user_ctx,
+  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
                            SchemaIdentifier::const_reference schema_identifier,
                            bool send_error= true);
 
   /** Server API method for checking table authorization */
-  static bool isAuthorized(const SecurityContext &user_ctx,
+  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
                            TableIdentifier &table_identifier,
                            bool send_error= true);
 
   /** Server API method for checking process authorization */
-  static bool isAuthorized(const SecurityContext &user_ctx,
+  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
                            const Session *session,
                            bool send_error= true);
 
@@ -101,7 +100,7 @@
    * Server API helper method for applying authorization tests
    * to a set of schema names (for use in the context of getSchemaNames
    */
-  static void pruneSchemaNames(const SecurityContext &user_ctx,
+  static void pruneSchemaNames(drizzled::identifier::User::const_shared_ptr user_ctx,
                                SchemaIdentifier::vector &set_of_schemas);
   
   /**
@@ -112,14 +111,14 @@
 
 };
 
-inline bool Authorization::restrictTable(const SecurityContext &user_ctx,
+inline bool Authorization::restrictTable(const drizzled::identifier::User &user_ctx,
                                          TableIdentifier &table)
 {
   return restrictSchema(user_ctx, table);
 }
 
-inline bool Authorization::restrictProcess(const SecurityContext &,
-                                           const SecurityContext &)
+inline bool Authorization::restrictProcess(const drizzled::identifier::User &,
+                                           const drizzled::identifier::User &)
 {
   return false;
 }

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2010-12-08 03:14:32 +0000
+++ drizzled/plugin/schema_engine.cc	2010-12-18 05:18:30 +0000
@@ -58,7 +58,7 @@
   std::for_each(StorageEngine::getSchemaEngines().begin(), StorageEngine::getSchemaEngines().end(),
            AddSchemaNames(schemas));
 
-  plugin::Authorization::pruneSchemaNames(session.getSecurityContext(), schemas);
+  plugin::Authorization::pruneSchemaNames(session.user(), schemas);
 }
 
 class StorageEngineGetSchemaDefinition: public std::unary_function<StorageEngine *, bool>

=== removed file 'drizzled/security_context.h'
--- drizzled/security_context.h	2010-10-16 11:09:48 +0000
+++ drizzled/security_context.h	1970-01-01 00:00:00 +0000
@@ -1,95 +0,0 @@
-/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
- *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
- *
- *  Copyright (C) 2008 Sun Microsystems
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
-
-
-#ifndef DRIZZLED_SECURITY_CONTEXT_H
-#define DRIZZLED_SECURITY_CONTEXT_H
-
-#include <string>
-
-namespace drizzled
-{
-
-/**
-  @class SecurityContext
-  @brief A set of Session members describing the current authenticated user.
-*/
-
-class SecurityContext {
-public:
-  enum PasswordType
-  {
-    PLAIN_TEXT,
-    MYSQL_HASH
-  };
-
-  SecurityContext():
-    password_type(PLAIN_TEXT)
-  { }
-
-  const std::string& getIp() const
-  {
-    return ip;
-  }
-
-  void setIp(const char *newip)
-  {
-    ip.assign(newip);
-  }
-
-  const std::string& getUser() const
-  {
-    return user;
-  }
-
-  void setUser(const std::string &newuser)
-  {
-    user.assign(newuser);
-  }
-
-  PasswordType getPasswordType(void) const
-  {
-    return password_type;
-  }
-
-  void setPasswordType(PasswordType newpassword_type)
-  {
-    password_type= newpassword_type;
-  }
-
-  const std::string& getPasswordContext() const
-  {
-    return password_context;
-  }
-
-  void setPasswordContext(const char *newpassword_context, size_t size)
-  {
-    password_context.assign(newpassword_context, size);
-  }
-
-private:
-  PasswordType password_type;
-  std::string user;
-  std::string ip;
-  std::string password_context;
-};
-
-} /* namespace drizzled */
-
-#endif /* DRIZZLED_SECURITY_CONTEXT_H */

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-12-18 02:06:13 +0000
+++ drizzled/session.cc	2010-12-18 06:42:10 +0000
@@ -49,6 +49,8 @@
 #include "drizzled/transaction_services.h"
 #include "drizzled/drizzled.h"
 
+#include "drizzled/identifier.h"
+
 #include "drizzled/table/instance.h"
 
 #include "plugin/myisam/myisam.h"
@@ -171,6 +173,8 @@
   scheduler(NULL),
   scheduler_arg(NULL),
   lock_id(&main_lock_id),
+  thread_stack(NULL),
+  security_ctx(identifier::User::make_shared()),
   user_time(0),
   ha_data(plugin::num_trx_monitored_objects),
   concurrent_execute_allowed(true),
@@ -203,7 +207,6 @@
     will be re-initialized in init_for_queries().
   */
   memory::init_sql_alloc(&main_mem_root, memory::ROOT_MIN_BLOCK_SIZE, 0);
-  thread_stack= NULL;
   count_cuted_fields= CHECK_FIELD_ERROR_FOR_NULL;
   col_access= 0;
   tmp_table= 0;
@@ -378,11 +381,15 @@
 
   if (client->isConnected())
   {
+    assert(security_ctx);
     if (global_system_variables.log_warnings)
-        errmsg_printf(ERRMSG_LVL_WARN, ER(ER_FORCING_CLOSE),internal::my_progname,
-                      thread_id,
-                      (getSecurityContext().getUser().c_str() ?
-                       getSecurityContext().getUser().c_str() : ""));
+    {
+      errmsg_printf(ERRMSG_LVL_WARN, ER(ER_FORCING_CLOSE),
+                    internal::my_progname,
+                    thread_id,
+                    security_ctx->username().c_str());
+    }
+
     disconnect(0, false);
   }
 
@@ -605,7 +612,7 @@
 */
 bool Session::isViewable() const
 {
-  return plugin::Authorization::isAuthorized(current_session->getSecurityContext(),
+  return plugin::Authorization::isAuthorized(current_session->user(),
                                              this,
                                              false);
 }
@@ -651,8 +658,7 @@
                         const std::string &in_db)
 {
   bool is_authenticated=
-    plugin::Authentication::isAuthenticated(getSecurityContext(),
-                                            passwd_str);
+    plugin::Authentication::isAuthenticated(user(), passwd_str);
 
   if (is_authenticated != true)
   {
@@ -1660,13 +1666,11 @@
   {
     if (not getKilled() && variables.log_warnings > 1)
     {
-      SecurityContext *sctx= &security_ctx;
-
       errmsg_printf(ERRMSG_LVL_WARN, ER(ER_NEW_ABORTING_CONNECTION)
                   , thread_id
                   , (_schema->empty() ? "unconnected" : _schema->c_str())
-                  , sctx->getUser().empty() == false ? sctx->getUser().c_str() : "unauthenticated"
-                  , sctx->getIp().c_str()
+                  , security_ctx->username().empty() == false ? security_ctx->username().c_str() : "unauthenticated"
+                  , security_ctx->address().c_str()
                   , (main_da.is_error() ? main_da.message() : ER(ER_UNKNOWN_ERROR)));
     }
   }

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-12-09 13:44:51 +0000
+++ drizzled/session.h	2010-12-18 05:18:30 +0000
@@ -47,7 +47,7 @@
 #include <map>
 #include <string>
 
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/open_tables_state.h"
 #include "drizzled/internal_error_handler.h"
 #include "drizzled/diagnostics_area.h"
@@ -567,7 +567,7 @@
   char *thread_stack;
 
 private:
-  SecurityContext security_ctx;
+  identifier::User::shared_ptr security_ctx;
 
   int32_t scoreboard_index;
 
@@ -576,14 +576,17 @@
     assert(this->dbug_sentry == Session_SENTRY_MAGIC);
   }
 public:
-  const SecurityContext& getSecurityContext() const
+  identifier::User::const_shared_ptr user() const
   {
-    return security_ctx;
+    if (security_ctx)
+      return security_ctx;
+
+    return identifier::User::const_shared_ptr();
   }
 
-  SecurityContext& getSecurityContext()
+  void setUser(identifier::User::shared_ptr arg)
   {
-    return security_ctx;
+    security_ctx= arg;
   }
 
   int32_t getScoreboardIndex()

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2010-12-16 21:42:18 +0000
+++ drizzled/sql_base.cc	2010-12-18 05:18:30 +0000
@@ -1633,8 +1633,7 @@
      * table/schema information via error messages
      */
     TableIdentifier the_table(tables->getSchemaName(), tables->getTableName());
-    if (not plugin::Authorization::isAuthorized(getSecurityContext(),
-                                                the_table))
+    if (not plugin::Authorization::isAuthorized(user(), the_table))
     {
       result= -1;                               // Fatal error
       break;

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2010-12-11 17:34:45 +0000
+++ drizzled/statement/create_schema.cc	2010-12-18 05:18:30 +0000
@@ -76,7 +76,7 @@
   if (not identifier.isValid())
     return false;
 
-  if (not plugin::Authorization::isAuthorized(getSession()->getSecurityContext(), identifier))
+  if (not plugin::Authorization::isAuthorized(getSession()->user(), identifier))
     return false;
 
   if (not is_if_not_exists)

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-12-16 21:42:18 +0000
+++ drizzled/table.cc	2010-12-18 05:18:30 +0000
@@ -335,7 +335,7 @@
 
 bool check_db_name(Session *session, SchemaIdentifier &schema_identifier)
 {
-  if (not plugin::Authorization::isAuthorized(session->getSecurityContext(), schema_identifier))
+  if (not plugin::Authorization::isAuthorized(session->user(), schema_identifier))
   {
     return false;
   }

=== modified file 'plugin/auth_file/auth_file.cc'
--- plugin/auth_file/auth_file.cc	2010-12-02 21:58:09 +0000
+++ plugin/auth_file/auth_file.cc	2010-12-18 05:18:30 +0000
@@ -29,7 +29,7 @@
 
 #include "drizzled/configmake.h"
 #include "drizzled/plugin/authentication.h"
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/util/convert.h"
 #include "drizzled/algorithm/sha1.h"
 #include "drizzled/module/option_map.h"
@@ -71,7 +71,7 @@
   /**
    * Base class method to check authentication for a user.
    */
-  bool authenticate(const SecurityContext &sctx, const string &password);
+  bool authenticate(const identifier::User &sctx, const string &password);
 
   /**
    * Verify the local and remote scrambled password match using the MySQL
@@ -202,13 +202,13 @@
   return memcmp(local_scrambled_password, scrambled_password_check, SHA1_DIGEST_LENGTH) == 0;
 }
 
-bool AuthFile::authenticate(const SecurityContext &sctx, const string &password)
+bool AuthFile::authenticate(const identifier::User &sctx, const string &password)
 {
-  std::map<std::string, std::string>::const_iterator user= users.find(sctx.getUser());
+  std::map<std::string, std::string>::const_iterator user= users.find(sctx.username());
   if (user == users.end())
     return false;
 
-  if (sctx.getPasswordType() == SecurityContext::MYSQL_HASH)
+  if (sctx.getPasswordType() == identifier::User::MYSQL_HASH)
     return verifyMySQLHash(user->second, sctx.getPasswordContext(), password);
 
   if (password == user->second)

=== modified file 'plugin/auth_http/auth_http.cc'
--- plugin/auth_http/auth_http.cc	2010-11-18 03:56:22 +0000
+++ plugin/auth_http/auth_http.cc	2010-12-18 05:18:30 +0000
@@ -25,7 +25,7 @@
 #include <cassert>
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/plugin/authentication.h"
 #include "drizzled/gettext.h"
 namespace po= boost::program_options;
@@ -73,23 +73,23 @@
     curl_global_cleanup();
   }
 
-  virtual bool authenticate(const SecurityContext &sctx, const string &password)
+  virtual bool authenticate(const identifier::User &sctx, const string &password)
   {
     long http_response_code;
 
-    assert(sctx.getUser().c_str());
+    assert(sctx.username().c_str());
 
     // set the parameters: url, username, password
     rv= curl_easy_setopt(curl_handle, CURLOPT_URL, auth_url.c_str());
 #if defined(HAVE_CURLOPT_USERNAME)
 
     rv= curl_easy_setopt(curl_handle, CURLOPT_USERNAME,
-                         sctx.getUser().c_str());
+                         sctx.username().c_str());
     rv= curl_easy_setopt(curl_handle, CURLOPT_PASSWORD, password.c_str());
 
 #else
 
-    string userpwd(sctx.getUser());
+    string userpwd(sctx.username());
     userpwd.append(":");
     userpwd.append(password);
     rv= curl_easy_setopt(curl_handle, CURLOPT_USERPWD, userpwd.c_str());

=== modified file 'plugin/auth_ldap/auth_ldap.cc'
--- plugin/auth_ldap/auth_ldap.cc	2010-12-05 07:35:32 +0000
+++ plugin/auth_ldap/auth_ldap.cc	2010-12-18 05:18:30 +0000
@@ -29,7 +29,7 @@
 #include <string>
 
 #include "drizzled/plugin/authentication.h"
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/util/convert.h"
 #include "drizzled/algorithm/sha1.h"
 
@@ -99,7 +99,7 @@
   /**
    * Base class method to check authentication for a user.
    */
-  bool authenticate(const SecurityContext &sctx, const string &password);
+  bool authenticate(const identifier::User &sctx, const string &password);
 
   /**
    * Lookup a user in LDAP.
@@ -200,7 +200,7 @@
   return error;
 }
 
-bool AuthLDAP::authenticate(const SecurityContext &sctx, const string &password)
+bool AuthLDAP::authenticate(const identifier::User &sctx, const string &password)
 {
   /* See if cache should be emptied. */
   if (cache_timeout > 0)
@@ -222,7 +222,7 @@
 
   pthread_rwlock_rdlock(&lock);
 
-  AuthLDAP::UserCache::const_iterator user= users.find(sctx.getUser());
+  AuthLDAP::UserCache::const_iterator user= users.find(sctx.username());
   if (user == users.end())
   {
     pthread_rwlock_unlock(&lock);
@@ -230,16 +230,16 @@
     pthread_rwlock_wrlock(&lock);
 
     /* Make sure the user was not added while we unlocked. */
-    user= users.find(sctx.getUser());
+    user= users.find(sctx.username());
     if (user == users.end())
-      lookupUser(sctx.getUser());
+      lookupUser(sctx.username());
 
     pthread_rwlock_unlock(&lock);
 
     pthread_rwlock_rdlock(&lock);
 
     /* Get user again because map may have changed while unlocked. */
-    user= users.find(sctx.getUser());
+    user= users.find(sctx.username());
     if (user == users.end())
     {
       pthread_rwlock_unlock(&lock);
@@ -253,7 +253,7 @@
     return false;
   }
 
-  if (sctx.getPasswordType() == SecurityContext::MYSQL_HASH)
+  if (sctx.getPasswordType() == identifier::User::MYSQL_HASH)
   {
     bool allow= verifyMySQLHash(user->second, sctx.getPasswordContext(), password);
     pthread_rwlock_unlock(&lock);

=== modified file 'plugin/auth_pam/auth_pam.cc'
--- plugin/auth_pam/auth_pam.cc	2010-05-18 18:20:56 +0000
+++ plugin/auth_pam/auth_pam.cc	2010-12-18 05:18:30 +0000
@@ -29,7 +29,7 @@
 #include <security/pam_misc.h>
 #endif
 
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/plugin/authentication.h"
 
 using namespace drizzled;
@@ -106,7 +106,7 @@
 public:
   Auth_pam(std::string name_arg)
     : drizzled::plugin::Authentication(name_arg) {}
-  virtual bool authenticate(const SecurityContext &sctx,
+  virtual bool authenticate(const identifier::User &sctx,
                             const std::string &password)
   {
     int retval;
@@ -114,7 +114,7 @@
     struct pam_conv conv_info= { &auth_pam_talker, (void*)&userinfo };
     pam_handle_t *pamh= NULL;
 
-    userinfo.name= sctx.getUser().c_str();
+    userinfo.name= sctx.username().c_str();
     userinfo.password= password.c_str();
 
     retval= pam_start("drizzle", userinfo.name, &conv_info, &pamh);

=== modified file 'plugin/auth_test/auth_test.cc'
--- plugin/auth_test/auth_test.cc	2010-06-23 20:51:16 +0000
+++ plugin/auth_test/auth_test.cc	2010-12-18 05:18:30 +0000
@@ -22,7 +22,7 @@
 #include <string>
 
 #include "drizzled/plugin/authentication.h"
-#include "drizzled/security_context.h"
+#include "drizzled/identifier.h"
 #include "drizzled/util/convert.h"
 #include "drizzled/algorithm/sha1.h"
 
@@ -42,23 +42,23 @@
     plugin::Authentication(name_arg)
   { }
 
-  virtual bool authenticate(const SecurityContext &sctx, const string &password)
+  virtual bool authenticate(const identifier::User &sctx, const string &password)
   {
     /* The "root" user always succeeds for drizzletest to get in. */
-    if (sctx.getUser() == "root" && password.empty())
+    if (sctx.username() == "root" && password.empty())
       return true;
 
     /* Any password succeeds. */
-    if (sctx.getUser() == "password_ok" && !password.empty())
+    if (sctx.username() == "password_ok" && !password.empty())
       return true;
 
     /* No password succeeds. */
-    if (sctx.getUser() == "no_password_ok" && password.empty())
+    if (sctx.username() == "no_password_ok" && password.empty())
       return true;
 
     /* Check if MySQL password scramble succeeds. */
-    if (sctx.getUser() == "scramble_ok" &&
-        sctx.getPasswordType() == SecurityContext::MYSQL_HASH &&
+    if (sctx.username() == "scramble_ok" &&
+        sctx.getPasswordType() == identifier::User::MYSQL_HASH &&
         sctx.getPasswordContext().size() == SHA1_DIGEST_LENGTH &&
         password.size() == SHA1_DIGEST_LENGTH)
     {

=== modified file 'plugin/console/console.cc'
--- plugin/console/console.cc	2010-12-16 02:16:37 +0000
+++ plugin/console/console.cc	2010-12-18 05:18:30 +0000
@@ -99,7 +99,9 @@
   virtual bool authenticate(void)
   {
     printDebug("authenticate");
-    session->getSecurityContext().setUser(username);
+    identifier::User::shared_ptr user= identifier::User::make_shared();
+    user->setUser(username);
+    session->setUser(user);
     return session->checkUser(password, db);
   }
 

=== modified file 'plugin/drizzle_protocol/drizzle_protocol.cc'
--- plugin/drizzle_protocol/drizzle_protocol.cc	2010-12-13 14:34:37 +0000
+++ plugin/drizzle_protocol/drizzle_protocol.cc	2010-12-18 05:18:30 +0000
@@ -77,10 +77,10 @@
 
 bool ClientDrizzleProtocol::isAdminAllowed(void)
 {
-  if (std::find(drizzle_admin_ip_addresses.begin(), drizzle_admin_ip_addresses.end(), session->getSecurityContext().getIp()) != drizzle_admin_ip_addresses.end())
+  if (std::find(drizzle_admin_ip_addresses.begin(), drizzle_admin_ip_addresses.end(), session->user()->address()) != drizzle_admin_ip_addresses.end())
     return true;
-  else
-    return false;
+
+  return false;
 }
 
 plugin::Client *ListenDrizzleProtocol::getClient(int fd)

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-12-16 02:16:37 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-12-18 05:18:30 +0000
@@ -1177,13 +1177,15 @@
            use the default max length */
 {
   Session *session= reinterpret_cast<Session *>(in_session);
+  drizzled::identifier::User::const_shared_ptr user_identifier(session->user());
+
   fprintf(f,
           "Drizzle thread %"PRIu64", query id %"PRIu64", %s, %s, %s ",
           static_cast<uint64_t>(session->getSessionId()),
           static_cast<uint64_t>(session->getQueryId()),
           glob_hostname,
-          session->getSecurityContext().getIp().c_str(),
-          session->getSecurityContext().getUser().c_str()
+          user_identifier->address().c_str(),
+          user_identifier->username().c_str()
   );
   fprintf(f, "\n%s", session->getQueryString()->c_str());
   putc('\n', f);

=== modified file 'plugin/logging_stats/logging_stats.cc'
--- plugin/logging_stats/logging_stats.cc	2010-12-05 07:35:32 +0000
+++ plugin/logging_stats/logging_stats.cc	2010-12-18 05:18:30 +0000
@@ -210,8 +210,8 @@
        the scoreboard would be filled up quickly with invalid users. 
     */
     scoreboard_slot= new ScoreboardSlot();
-    scoreboard_slot->setUser(session->getSecurityContext().getUser());
-    scoreboard_slot->setIp(session->getSecurityContext().getIp());
+    scoreboard_slot->setUser(session->user()->username());
+    scoreboard_slot->setIp(session->user()->address());
   }
 
   scoreboard_slot->getStatusVars()->logStatusVar(session);

=== modified file 'plugin/logging_stats/scoreboard.cc'
--- plugin/logging_stats/scoreboard.cc	2010-08-18 02:17:48 +0000
+++ plugin/logging_stats/scoreboard.cc	2010-12-18 05:18:30 +0000
@@ -166,8 +166,8 @@
       {
         scoreboard_slot->setInUse(true);
         scoreboard_slot->setSessionId(session->getSessionId());
-        scoreboard_slot->setUser(session->getSecurityContext().getUser());
-        scoreboard_slot->setIp(session->getSecurityContext().getIp());
+        scoreboard_slot->setUser(session->user()->username());
+        scoreboard_slot->setIp(session->user()->address());
         session->setScoreboardIndex(slot_index);
         LOCK_scoreboard_vector->unlock();
         return scoreboard_slot; 

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2010-12-17 08:22:10 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2010-12-18 06:42:10 +0000
@@ -34,6 +34,8 @@
 #include "options.h"
 #include "table_function.h"
 
+#include "drizzled/identifier.h"
+
 #define PROTOCOL_VERSION 10
 
 namespace po= boost::program_options;
@@ -663,6 +665,7 @@
   uint32_t pkt_len= 0;
   char *end;
   char scramble[SCRAMBLE_LENGTH];
+  identifier::User::shared_ptr user_identifier= identifier::User::make_shared();
 
   makeScramble(scramble);
 
@@ -673,11 +676,11 @@
 
     if (drizzleclient_net_peer_addr(&net, ip, &peer_port, NI_MAXHOST))
     {
-      my_error(ER_BAD_HOST_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+      my_error(ER_BAD_HOST_ERROR, MYF(0), ip);
       return false;
     }
 
-    session->getSecurityContext().setIp(ip);
+    user_identifier->setAddress(ip);
   }
   drizzleclient_net_keepalive(&net, true);
 
@@ -732,7 +735,7 @@
         ||    (pkt_len= drizzleclient_net_read(&net)) == packet_error 
         || pkt_len < MIN_HANDSHAKE_SIZE)
     {
-      my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+      my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
       return false;
     }
   }
@@ -742,7 +745,7 @@
   client_capabilities= uint2korr(net.read_pos);
   if (!(client_capabilities & CLIENT_PROTOCOL_MYSQL41))
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -758,7 +761,7 @@
 
   if (end >= (char*) net.read_pos + pkt_len + 2)
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -782,12 +785,14 @@
     passwd_len= (unsigned char)(*passwd++);
     if (passwd_len > 0)
     {
-      session->getSecurityContext().setPasswordType(SecurityContext::MYSQL_HASH);
-      session->getSecurityContext().setPasswordContext(scramble, SCRAMBLE_LENGTH);
+      user_identifier->setPasswordType(identifier::User::MYSQL_HASH);
+      user_identifier->setPasswordContext(scramble, SCRAMBLE_LENGTH);
     }
   }
   else
+  {
     passwd_len= 0;
+  }
 
   if (client_capabilities & CLIENT_CONNECT_WITH_DB &&
       passwd < (char *) net.read_pos + pkt_len)
@@ -795,14 +800,16 @@
     l_db= l_db + passwd_len + 1;
   }
   else
+  {
     l_db= NULL;
+  }
 
   /* strlen() can't be easily deleted without changing client */
   uint32_t db_len= l_db ? strlen(l_db) : 0;
 
   if (passwd + passwd_len + db_len > (char *) net.read_pos + pkt_len)
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -827,7 +834,8 @@
     }
   }
 
-  session->getSecurityContext().setUser(user);
+  user_identifier->setUser(user);
+  session->setUser(user_identifier);
 
   return session->checkUser(string(passwd, passwd_len),
                             string(l_db ? l_db : ""));
@@ -836,10 +844,10 @@
 
 bool ClientMySQLProtocol::isAdminAllowed(void)
 {
-  if (std::find(mysql_admin_ip_addresses.begin(), mysql_admin_ip_addresses.end(), session->getSecurityContext().getIp()) != mysql_admin_ip_addresses.end())
+  if (std::find(mysql_admin_ip_addresses.begin(), mysql_admin_ip_addresses.end(), session->user()->address()) != mysql_admin_ip_addresses.end())
     return true;
-  else
-    return false;
+
+  return false;
 }
 
 bool ClientMySQLProtocol::netStoreData(const unsigned char *from, size_t length)

=== modified file 'plugin/session_dictionary/processlist.cc'
--- plugin/session_dictionary/processlist.cc	2010-12-16 21:20:57 +0000
+++ plugin/session_dictionary/processlist.cc	2010-12-18 05:18:30 +0000
@@ -66,19 +66,19 @@
   while ((tmp= session_generator))
   {
     drizzled::Session::State::const_shared_ptr state(tmp->state());
-    const SecurityContext *tmp_sctx= &tmp->getSecurityContext();
+    identifier::User::const_shared_ptr tmp_sctx= tmp->user();
 
     /* ID */
     push((int64_t) tmp->thread_id);
 
     /* USER */
-    if (not tmp_sctx->getUser().empty())
-      push(tmp_sctx->getUser());
+    if (not tmp_sctx->username().empty())
+      push(tmp_sctx->username());
     else 
       push(_("no user"));
 
     /* HOST */
-    push(tmp_sctx->getIp());
+    push(tmp_sctx->address());
 
     /* DB */
     drizzled::util::string::const_shared_ptr schema(tmp->schema());

=== modified file 'plugin/simple_user_policy/policy.h'
--- plugin/simple_user_policy/policy.h	2010-12-11 17:34:45 +0000
+++ plugin/simple_user_policy/policy.h	2010-12-18 05:18:30 +0000
@@ -36,29 +36,30 @@
     drizzled::plugin::Authorization("Simple User Policy")
   { }
 
-  virtual bool restrictSchema(const drizzled::SecurityContext &user_ctx,
+  virtual bool restrictSchema(const drizzled::identifier::User &user_ctx,
                               drizzled::SchemaIdentifier::const_reference schema);
 
-  virtual bool restrictProcess(const drizzled::SecurityContext &user_ctx,
-                               const drizzled::SecurityContext &session_ctx);
+  virtual bool restrictProcess(const drizzled::identifier::User &user_ctx,
+                               const drizzled::identifier::User &session_ctx);
 };
 
-inline bool Policy::restrictSchema(const drizzled::SecurityContext &user_ctx,
+inline bool Policy::restrictSchema(const drizzled::identifier::User &user_ctx,
                                    drizzled::SchemaIdentifier::const_reference schema)
 {
-  if ((user_ctx.getUser() == "root")
+  if ((user_ctx.username() == "root")
       || schema.compare("data_dictionary")
       || schema.compare("information_schema"))
     return false;
-  return not schema.compare(user_ctx.getUser());
+  return not schema.compare(user_ctx.username());
 }
 
-inline bool Policy::restrictProcess(const drizzled::SecurityContext &user_ctx,
-                                    const drizzled::SecurityContext &session_ctx)
+inline bool Policy::restrictProcess(const drizzled::identifier::User &user_ctx,
+                                    const drizzled::identifier::User &session_ctx)
 {
-  if (user_ctx.getUser() == "root")
+  if (user_ctx.username() == "root")
     return false;
-  return user_ctx.getUser() != session_ctx.getUser();
+
+  return user_ctx.username() != session_ctx.username();
 }
 
 } /* namespace simple_user_policy */

=== modified file 'plugin/user_locks/barriers.h'
--- plugin/user_locks/barriers.h	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/barriers.h	2010-12-18 05:18:30 +0000
@@ -21,7 +21,6 @@
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/condition_variable.hpp>
 #include <boost/unordered_map.hpp>
-#include <boost/logic/tribool.hpp>
 #include <boost/unordered/unordered_set.hpp>
 
 #include <string>

=== modified file 'plugin/user_locks/create_barrier.cc'
--- plugin/user_locks/create_barrier.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/create_barrier.cc	2010-12-18 05:18:30 +0000
@@ -40,24 +40,22 @@
 
   barriers::Storable *list= static_cast<barriers::Storable *>(getSession().getProperty(barriers::property_key));
 
-  boost::tribool result;
+  bool result;
 
+  drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
   if (arg_count == 2)
   {
     int64_t wait_for;
     wait_for= args[1]->val_int();
 
-    result= Barriers::getInstance().create(Key(getSession().getSecurityContext(), res->c_str()), getSession().getSessionId(), wait_for);
+    result= Barriers::getInstance().create(Key(*user_identifier, res->c_str()), getSession().getSessionId(), wait_for);
   }
   else
   {
-    result= Barriers::getInstance().create(Key(getSession().getSecurityContext(), res->c_str()), getSession().getSessionId());
+    result= Barriers::getInstance().create(Key(*user_identifier, res->c_str()), getSession().getSessionId());
   }
 
 
-  if (boost::indeterminate(result))
-    null_value= true;
-
   if (result)
   {
     if (not list)
@@ -66,7 +64,7 @@
       getSession().setProperty(barriers::property_key, list);
     }
 
-    list->insert(Key(getSession().getSecurityContext(), res->c_str()));
+    list->insert(Key(*user_identifier, res->c_str()));
 
     return 1;
   }

=== modified file 'plugin/user_locks/get_lock.cc'
--- plugin/user_locks/get_lock.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/get_lock.cc	2010-12-18 05:18:30 +0000
@@ -43,18 +43,17 @@
   }
   null_value= false;
 
-  std::cerr << "Trying to create " << res->c_str() << "\n";
-
   user_locks::Storable *list= static_cast<user_locks::Storable *>(getSession().getProperty("user_locks"));
   if (list) // To be compatible with MySQL, we will now release all other locks we might have.
     list->erase_all();
 
   bool result;
+  drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
 
     try {
-      result= user_locks::Locks::getInstance().lock(getSession().getSessionId(), Key(getSession().getSecurityContext(), res->c_str()), wait_time);
+      result= user_locks::Locks::getInstance().lock(getSession().getSessionId(), Key(*user_identifier, res->c_str()), wait_time);
     }
     catch(boost::thread_interrupted const& error)
     {
@@ -65,9 +64,6 @@
     }
   }
 
-  if (boost::indeterminate(result))
-    null_value= true;
-
   if (result)
   {
     if (not list)
@@ -76,7 +72,7 @@
       getSession().setProperty("user_locks", list);
     }
 
-    list->insert(Key(getSession().getSecurityContext(), res->c_str()));
+    list->insert(Key(*user_identifier, res->c_str()));
 
     return 1;
   }

=== modified file 'plugin/user_locks/get_locks.cc'
--- plugin/user_locks/get_locks.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/get_locks.cc	2010-12-18 05:18:30 +0000
@@ -36,7 +36,7 @@
 
     if (res && res->length())
     {
-      list_of_locks.insert(Key(getSession().getSecurityContext(), res->c_str()));
+      list_of_locks.insert(Key(*getSession().user(), res->c_str()));
     }
     else
     {
@@ -45,7 +45,7 @@
     }
   }
 
-  boost::tribool result;
+  bool result;
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
 
@@ -61,9 +61,6 @@
     }
   }
 
-  if (boost::indeterminate(result))
-    null_value= true;
-
   if (result)
   {
     user_locks::Storable *list= static_cast<user_locks::Storable *>(getSession().getProperty("user_locks"));

=== modified file 'plugin/user_locks/is_free_lock.cc'
--- plugin/user_locks/is_free_lock.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/is_free_lock.cc	2010-12-18 05:18:30 +0000
@@ -37,7 +37,7 @@
   null_value= false;
 
   drizzled::session_id_t id= getSession().getSessionId();
-  bool result= user_locks::Locks::getInstance().release(user_locks::Key(getSession().getSecurityContext(), res->c_str()), id);
+  bool result= user_locks::Locks::getInstance().release(user_locks::Key(*getSession().user(), res->c_str()), id);
 
   return result ? 1 : 0;
 }

=== modified file 'plugin/user_locks/is_used_lock.cc'
--- plugin/user_locks/is_used_lock.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/is_used_lock.cc	2010-12-18 05:18:30 +0000
@@ -37,7 +37,7 @@
   null_value= false;
 
   drizzled::session_id_t id;
-  bool result= user_locks::Locks::getInstance().isUsed(Key(getSession().getSecurityContext(), res->c_str()), id);
+  bool result= user_locks::Locks::getInstance().isUsed(Key(*getSession().user(), res->c_str()), id);
 
   if (not result)
   {

=== modified file 'plugin/user_locks/key.h'
--- plugin/user_locks/key.h	2010-10-13 02:49:48 +0000
+++ plugin/user_locks/key.h	2010-12-18 05:18:30 +0000
@@ -21,7 +21,6 @@
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/condition_variable.hpp>
 #include <boost/unordered_map.hpp>
-#include <boost/logic/tribool.hpp>
 #include <boost/unordered/unordered_set.hpp>
 
 #include <string>
@@ -36,17 +35,17 @@
 namespace user_locks {
 
 class Key {
-  drizzled::SecurityContext context;
+  drizzled::identifier::User context;
   std::string lock_name;
   size_t hash_value;
 
 public:
-  Key(const drizzled::SecurityContext &context_arg, const std::string &lock_name_arg) :
+  Key(const drizzled::identifier::User &context_arg, const std::string &lock_name_arg) :
     context(context_arg),
     lock_name(lock_name_arg)
   {
     drizzled::util::insensitive_hash hasher;
-    hash_value= hasher(context.getUser() + lock_name_arg);
+    hash_value= hasher(context.username() + lock_name_arg);
   }
 
   size_t getHashValue() const
@@ -61,9 +60,8 @@
 
   const std::string &getUser() const
   {
-    return context.getUser();
+    return context.username();
   }
-
 };
 
 bool operator==(Key const& left, Key const& right);

=== modified file 'plugin/user_locks/release_barrier.cc'
--- plugin/user_locks/release_barrier.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/release_barrier.cc	2010-12-18 05:18:30 +0000
@@ -39,7 +39,9 @@
   }
 
 
-  barriers::return_t result= Barriers::getInstance().release(Key(getSession().getSecurityContext(), res->c_str()), getSession().getSessionId());
+  drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
+
+  barriers::return_t result= Barriers::getInstance().release(Key(*user_identifier, res->c_str()), getSession().getSessionId());
 
   switch (result)
   {
@@ -55,7 +57,7 @@
 
         return 0;
       }
-      list->erase(Key(getSession().getSecurityContext(), res->c_str()));
+      list->erase(Key(*user_identifier, res->c_str()));
       null_value= false;
 
       return 1;

=== modified file 'plugin/user_locks/release_lock.cc'
--- plugin/user_locks/release_lock.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/release_lock.cc	2010-12-18 05:18:30 +0000
@@ -37,12 +37,13 @@
   }
   null_value= false;
 
+  drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
   drizzled::session_id_t id= getSession().getSessionId();
   locks::return_t result;
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
     try {
-      result= user_locks::Locks::getInstance().release(Key(getSession().getSecurityContext(), res->c_str()), id);
+      result= user_locks::Locks::getInstance().release(Key(*user_identifier, res->c_str()), id);
     }
     catch(boost::thread_interrupted const& error)
     {
@@ -59,7 +60,7 @@
       user_locks::Storable *list= static_cast<user_locks::Storable *>(getSession().getProperty("user_locks"));
       assert(list);
       if (list) // Just in case we ever blow the assert
-        list->erase(Key(getSession().getSecurityContext(), res->c_str()));
+        list->erase(Key(*user_identifier, res->c_str()));
 
       return 1;
     }

=== modified file 'plugin/user_locks/release_wait.cc'
--- plugin/user_locks/release_wait.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/release_wait.cc	2010-12-18 05:18:30 +0000
@@ -38,12 +38,14 @@
   }
   null_value= false;
 
+  drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
   drizzled::session_id_t id= getSession().getSessionId();
   locks::return_t result;
+
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
     try {
-      result= user_locks::Locks::getInstance().release(Key(getSession().getSecurityContext(), res->c_str()), id, true);
+      result= user_locks::Locks::getInstance().release(Key(*user_identifier, res->c_str()), id, true);
     }
     catch(boost::thread_interrupted const& error)
     {
@@ -60,7 +62,7 @@
       user_locks::Storable *list= static_cast<user_locks::Storable *>(getSession().getProperty("user_locks"));
       assert(list);
       if (list) // Just in case we ever blow the assert
-        list->erase(Key(getSession().getSecurityContext(), res->c_str()));
+        list->erase(Key(*user_identifier, res->c_str()));
       return 1;
     }
   case locks::NOT_FOUND:

=== modified file 'plugin/user_locks/signal.cc'
--- plugin/user_locks/signal.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/signal.cc	2010-12-18 05:18:30 +0000
@@ -33,7 +33,7 @@
 
   if (res and res->length())
   {
-    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(getSession().getSecurityContext(), res->c_str()));
+    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(*getSession().user(), res->c_str()));
 
     if (barrier)
     {

=== modified file 'plugin/user_locks/wait.cc'
--- plugin/user_locks/wait.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/wait.cc	2010-12-18 05:18:30 +0000
@@ -33,7 +33,7 @@
 
   if (res and res->length())
   {
-    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(getSession().getSecurityContext(), res->c_str()));
+    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(*getSession().user(), res->c_str()));
 
     if (barrier and barrier->getOwner() == getSession().getSessionId())
     {

=== modified file 'plugin/user_locks/wait_for_lock.cc'
--- plugin/user_locks/wait_for_lock.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/wait_for_lock.cc	2010-12-18 05:18:30 +0000
@@ -43,7 +43,7 @@
 
   while (not found)
   {
-    found= user_locks::Locks::getInstance().isUsed(Key(getSession().getSecurityContext(), res->c_str()), id);
+    found= user_locks::Locks::getInstance().isUsed(Key(*getSession().user(), res->c_str()), id);
     if (not found)
     {
       boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());

=== modified file 'plugin/user_locks/wait_until.cc'
--- plugin/user_locks/wait_until.cc	2010-11-27 09:26:54 +0000
+++ plugin/user_locks/wait_until.cc	2010-12-18 05:18:30 +0000
@@ -34,7 +34,7 @@
 
   if (res and res->length() and wait_until)
   {
-    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(getSession().getSecurityContext(), res->c_str()));
+    Barrier::shared_ptr barrier= Barriers::getInstance().find(Key(*getSession().user(), res->c_str()));
 
     if (barrier and barrier->getOwner() == getSession().getSessionId())
     {

=== modified file 'plugin/utility_functions/tests/r/execute.result'
--- plugin/utility_functions/tests/r/execute.result	2010-12-15 21:28:47 +0000
+++ plugin/utility_functions/tests/r/execute.result	2010-12-18 05:18:30 +0000
@@ -1,63 +1,9 @@
-set @my_barrier= "barrier";
-SELECT CREATE_BARRIER(@my_barrier);
-CREATE_BARRIER(@my_barrier)
-1
-set @my_barrier= "barrier";
-SELECT CREATE_BARRIER(@my_barrier);
-CREATE_BARRIER(@my_barrier)
-0
 CREATE TABLE t1 (A VARCHAR(150));
 SET @execute= "SELECT WAIT('barrier')";
 INSERT INTO t1 VALUES (@execute), (@execute), (@execute);
-set @my_barrier= "barrier";
-SELECT USER_BARRIER_NAME FROM DATA_DICTIONARY.USER_DEFINED_BARRIERS WHERE USER_BARRIER_NAME=@my_barrier;
-USER_BARRIER_NAME
-barrier
-SELECT SIGNAL(@my_barrier);
-SIGNAL(@my_barrier)
-1
-SELECT EXECUTE(A) FROM t1;
-EXECUTE(A)
-1
-1
-1
-SELECT WAIT_UNTIL(@my_barrier, 3);
-WAIT_UNTIL(@my_barrier, 3)
-1
-SELECT USER,INFO FROM DATA_DICTIONARY.PROCESSLIST ORDER BY ID;
-USER	INFO
-root	SELECT USER,INFO FROM DATA_DICTIONARY.PROCESSLIST ORDER BY ID
-root	NULL
-root	SELECT WAIT('barrier')
-root	SELECT WAIT('barrier')
-root	SELECT WAIT('barrier')
-SELECT SIGNAL(@my_barrier);
-SIGNAL(@my_barrier)
-1
-TRUNCATE t1;
-SET @execute= "SELECT WAIT('barrier'), 2";
-INSERT INTO t1 VALUES (@execute), (@execute), (@execute);
-SELECT EXECUTE(A) FROM t1;
-EXECUTE(A)
-1
-1
-1
-SELECT WAIT_UNTIL(@my_barrier, 3);
-WAIT_UNTIL(@my_barrier, 3)
-1
-SELECT USER,INFO FROM DATA_DICTIONARY.PROCESSLIST ORDER BY ID;
-USER	INFO
-root	SELECT USER,INFO FROM DATA_DICTIONARY.PROCESSLIST ORDER BY ID
-root	NULL
-root	SELECT WAIT('barrier'), 2
-root	SELECT WAIT('barrier'), 2
-root	SELECT WAIT('barrier'), 2
-SELECT IF(KILL(ID), "YES", "NO") FROM DATA_DICTIONARY.PROCESSLIST WHERE INFO LIKE "%2";
-IF(KILL(ID), "YES", "NO")
-YES
-YES
-YES
-SELECT SIGNAL(@my_barrier);
-SIGNAL(@my_barrier)
+SELECT EXECUTE(A) FROM t1;
+EXECUTE(A)
+1
+1
 1
 DROP TABLE t1;

=== added file 'plugin/utility_functions/tests/t/execute.test'
--- plugin/utility_functions/tests/t/execute.test	1970-01-01 00:00:00 +0000
+++ plugin/utility_functions/tests/t/execute.test	2010-12-18 05:18:30 +0000
@@ -0,0 +1,8 @@
+# Simple test of execute
+
+CREATE TABLE t1 (A VARCHAR(150));
+SET @execute= "SELECT WAIT('barrier')";
+INSERT INTO t1 VALUES (@execute), (@execute), (@execute);
+SELECT EXECUTE(A) FROM t1;
+
+DROP TABLE t1;

=== renamed file 'plugin/utility_functions/tests/t/execute.test' => 'plugin/utility_functions/tests/t/execute_complex.disabled'
=== modified file 'plugin/utility_functions/user.cc'
--- plugin/utility_functions/user.cc	2010-10-21 20:21:18 +0000
+++ plugin/utility_functions/user.cc	2010-12-18 05:18:30 +0000
@@ -33,15 +33,16 @@
 String *User::val_str(String *str)
 {
   assert(fixed == 1);
-  Session *session= current_session;
-  if (session->getSecurityContext().getUser().empty())
+  identifier::User::const_shared_ptr user= getSession().user();
+  assert(user);
+  if (user->username().empty())
   {
     null_value= 1;
     return 0;
   }
   else
   {
-    str->copy(session->getSecurityContext().getUser().c_str(), session->getSecurityContext().getUser().length(), system_charset_info);
+    str->copy(user->username().c_str(), user->username().length(), system_charset_info);
   }
   return str;
 }

=== modified file 'support-files/drizzle.spec.in'
--- support-files/drizzle.spec.in	2010-10-28 07:19:07 +0000
+++ support-files/drizzle.spec.in	2010-12-18 08:22:53 +0000
@@ -368,7 +368,6 @@
 %{_includedir}/drizzled/query_id.h
 %{_includedir}/drizzled/records.h
 %{_includedir}/drizzled/replication_services.h
-%{_includedir}/drizzled/security_context.h
 %{_includedir}/drizzled/select_create.h
 %{_includedir}/drizzled/select_dump.h
 %{_includedir}/drizzled/select_dumpvar.h

=== modified file 'unittests/plugin/authentication_test.cc'
--- unittests/plugin/authentication_test.cc	2010-06-10 20:26:28 +0000
+++ unittests/plugin/authentication_test.cc	2010-12-18 05:18:30 +0000
@@ -22,7 +22,7 @@
 
 #include <drizzled/error.h>
 #include <drizzled/plugin/authentication.h>
-#include <drizzled/security_context.h>
+#include <drizzled/identifier.h>
 #include <gtest/gtest.h>
 #include <string>
 
@@ -40,15 +40,17 @@
 class AuthenticationTest : public ::testing::Test
 {
 public:
-  SecurityContext sctx;
+  identifier::User::const_shared_ptr sctx;
   std::string passwd;
   AuthenticationStub stub1;
   AuthenticationStub stub2;
 
   AuthenticationTest() :
+    sctx(drizzled::identifier::User::make_shared()),
     stub1("AuthenticationStub1"),
     stub2("AuthenticationStub2")
-  {}
+  {
+  }
   
   virtual void SetUp ()
   {

=== modified file 'unittests/plugin/plugin_stubs.h'
--- unittests/plugin/plugin_stubs.h	2010-06-10 20:26:28 +0000
+++ unittests/plugin/plugin_stubs.h	2010-12-18 05:18:30 +0000
@@ -231,7 +231,7 @@
     authenticate_return = value;
   }
 
-  virtual bool authenticate(const drizzled::SecurityContext &sctx, const std::string &passwd)
+  virtual bool authenticate(const drizzled::identifier::User &sctx, const std::string &passwd)
   {
     (void)sctx;
     (void)passwd;

